## ---------------------------------------------------------------------
## $Id: Config.cmake.in 31527 2013-11-03 09:58:45Z maier $
##
## Copyright (C) 2012 - 2013 by the deal.II authors
##
## This file is part of the deal.II library.
##
## The deal.II library is free software; you can use it, redistribute
## it, and/or modify it under the terms of the GNU Lesser General
## Public License as published by the Free Software Foundation; either
## version 2.1 of the License, or (at your option) any later version.
## The full text of the license can be found in the file LICENSE at
## the top level of the deal.II distribution.
##
## ---------------------------------------------------------------------


########################################################################
##                                                                    ##
##               The deal.II project configuration file               ##
##                                                                    ##
########################################################################


#
# General information
#

SET(DEAL_II_PACKAGE_NAME "deal.II")
SET(DEAL_II_PACKAGE_VERSION "8.1.0")
SET(DEAL_II_PACKAGE_VENDOR "The deal.II Authors <http://www.dealii.org/>")
SET(DEAL_II_PACKAGE_DESCRIPTION "Library for solving partial differential equations with the finite element method")

SET(DEAL_II_VERSION_MAJOR "8")
SET(DEAL_II_VERSION_MINOR "1")
SET(DEAL_II_VERSION "8.1")

SET(DEAL_II_PROJECT_CONFIG_NAME "deal.II")

SET(DEAL_II_BUILD_TYPE "DebugRelease")
SET(DEAL_II_BUILD_TYPES "DEBUG;RELEASE")


#
# Information about the project location
#

SET(DEAL_II_CMAKE_MACROS_RELDIR "share/deal.ii/cmake/macros")
SET(DEAL_II_COMMON_RELDIR "share/deal.II/common")
SET(DEAL_II_DOCREADME_RELDIR "share/doc/libdeal.ii-doc")
SET(DEAL_II_DOCHTML_RELDIR "share/doc/libdeal.ii-doc/html")
SET(DEAL_II_EXAMPLES_RELDIR "share/doc/libdeal.ii-doc/examples")
SET(DEAL_II_EXECUTABLE_RELDIR "bin")
SET(DEAL_II_INCLUDE_RELDIR "include")
SET(DEAL_II_LIBRARY_RELDIR "lib/x86_64-linux-gnu")
SET(DEAL_II_PROJECT_CONFIG_RELDIR "share/cmake/deal.II")

#
# Determine DEAL_II_PATH from CMAKE_CURRENT_LIST_DIR:
#

SET(DEAL_II_PATH "${CMAKE_CURRENT_LIST_DIR}")
SET(_path "${DEAL_II_PROJECT_CONFIG_RELDIR}")
WHILE(NOT "${_path}" STREQUAL "")
  GET_FILENAME_COMPONENT(DEAL_II_PATH "${DEAL_II_PATH}" PATH)
  GET_FILENAME_COMPONENT(_path "${_path}" PATH)
ENDWHILE()

#
# Print a message after inclusion of this file:
#

SET(DEAL_II_PROJECT_CONFIG_INCLUDED TRUE)

SET(DEAL_II_BUILD_DIR FALSE)

IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
  IF(DEAL_II_BUILD_DIR)
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} build directory found at ${DEAL_II_PATH}"
      )
  ELSE()
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} installation found at ${DEAL_II_PATH}"
      )
  ENDIF()
ENDIF()


#
# Include all convenience macros:
#

FILE(GLOB _macro_files
  "${DEAL_II_PATH}/${DEAL_II_CMAKE_MACROS_RELDIR}/macro_deal_ii*.cmake"
  )
FOREACH(file ${_macro_files})
  IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
    MESSAGE(STATUS "Include macro ${file}")
  ENDIF()
  INCLUDE(${file})
ENDFOREACH()


#
# Compiler and linker configuration
#

SET(DEAL_II_CXX_COMPILER "/usr/bin/c++")

# used for all targets:
SET(DEAL_II_CXX_FLAGS "-pedantic -fpic -Wall -Wpointer-arith -Wwrite-strings -Wsynth -Wsign-compare -Wswitch -Wno-unused-local-typedefs -Wno-long-long   -std=c++11 -g -O2 -fstack-protector-strong -Wformat -Werror=format-security -D_FORTIFY_SOURCE=2")

# _additionally_ used for debug targets:
SET(DEAL_II_CXX_FLAGS_DEBUG "-Og -ggdb -Wa,--compress-debug-sections")

# _additionally_ used for release targets:
SET(DEAL_II_CXX_FLAGS_RELEASE "-O2 -funroll-loops -funroll-all-loops -fstrict-aliasing -Wno-unused")

# used for all targets:
SET(DEAL_II_LINKER_FLAGS "-Wl,--as-needed -rdynamic -pthread -Wl,-z,relro")

# _additionally_ used for debug targets:
SET(DEAL_II_LINKER_FLAGS_DEBUG "-ggdb")

# _additionally_ used for release targets:
SET(DEAL_II_LINKER_FLAGS_RELEASE "")

# used for all targets:
SET(DEAL_II_USER_DEFINITIONS "")

# _additionally_ used for debug targets:
SET(DEAL_II_USER_DEFINITIONS_DEBUG "DEBUG")

# _additionally_ used for release targets:
SET(DEAL_II_USER_DEFINITIONS_RELEASE "")


#
# Build a static executable:
#

SET(DEAL_II_STATIC_EXECUTABLE "OFF")


#
# Information about include directories and libraries
#

# Full list of include directories:
SET(DEAL_II_INCLUDE_DIRS "${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR};${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II;${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II/bundled;/usr/include")

# Full list of libraries for the debug target:
SET(DEAL_II_LIBRARIES_DEBUG "${DEAL_II_PATH}/${DEAL_II_LIBRARY_RELDIR}/libdeal.ii.g.so;/usr/lib/x86_64-linux-gnu/libtbb.so;/usr/lib/x86_64-linux-gnu/libumfpack.so;/usr/lib/x86_64-linux-gnu/libcholmod.so;/usr/lib/x86_64-linux-gnu/libccolamd.so;/usr/lib/x86_64-linux-gnu/libcolamd.so;/usr/lib/x86_64-linux-gnu/libcamd.so;/usr/lib/x86_64-linux-gnu/libamd.so;/usr/lib/liblapack.so;/usr/lib/libblas.so;/usr/lib/gcc/x86_64-linux-gnu/5/libgfortran.so;/usr/lib/gcc/x86_64-linux-gnu/5/libquadmath.so;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/libc.so;/usr/lib/x86_64-linux-gnu/librt.so;/usr/lib/x86_64-linux-gnu/libboost_serialization.so;/usr/lib/x86_64-linux-gnu/libboost_system.so;/usr/lib/x86_64-linux-gnu/libboost_thread.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libz.so")

# Full list of libraries for the release target:
SET(DEAL_II_LIBRARIES_RELEASE "${DEAL_II_PATH}/${DEAL_II_LIBRARY_RELDIR}/libdeal.ii.so;/usr/lib/x86_64-linux-gnu/libtbb.so;/usr/lib/x86_64-linux-gnu/libumfpack.so;/usr/lib/x86_64-linux-gnu/libcholmod.so;/usr/lib/x86_64-linux-gnu/libccolamd.so;/usr/lib/x86_64-linux-gnu/libcolamd.so;/usr/lib/x86_64-linux-gnu/libcamd.so;/usr/lib/x86_64-linux-gnu/libamd.so;/usr/lib/liblapack.so;/usr/lib/libblas.so;/usr/lib/gcc/x86_64-linux-gnu/5/libgfortran.so;/usr/lib/gcc/x86_64-linux-gnu/5/libquadmath.so;/usr/lib/x86_64-linux-gnu/libm.so;/usr/lib/x86_64-linux-gnu/libc.so;/usr/lib/x86_64-linux-gnu/librt.so;/usr/lib/x86_64-linux-gnu/libboost_serialization.so;/usr/lib/x86_64-linux-gnu/libboost_system.so;/usr/lib/x86_64-linux-gnu/libboost_thread.so;/usr/lib/x86_64-linux-gnu/libpthread.so;/usr/lib/x86_64-linux-gnu/libz.so")

# Full list of libraries with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_LIBRARIES "debug;${DEAL_II_LIBRARIES_DEBUG};optimized;${DEAL_II_LIBRARIES_RELEASE}")


#
# Information about library targets
#

# The library targets file:
SET(DEAL_II_TARGET_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}Targets.cmake")

# The Debug target:
SET(DEAL_II_TARGET_DEBUG "deal.ii.g")

# The Release target:
SET(DEAL_II_TARGET_RELEASE "deal.ii")

# Full list of targets with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_TARGET "debug;${DEAL_II_TARGET_DEBUG};optimized;${DEAL_II_TARGET_RELEASE}")


#
# Feature configuration:
#

SET(DEAL_II_WITH_64BIT_INDICES OFF)
SET(DEAL_II_WITH_ARPACK OFF)
SET(DEAL_II_WITH_BOOST ON)
SET(DEAL_II_WITH_FUNCTIONPARSER OFF)
SET(DEAL_II_WITH_HDF5 OFF)
SET(DEAL_II_WITH_LAPACK ON)
SET(DEAL_II_WITH_METIS OFF)
SET(DEAL_II_WITH_MPI OFF)
SET(DEAL_II_WITH_MUMPS OFF)
SET(DEAL_II_WITH_NETCDF OFF)
SET(DEAL_II_WITH_P4EST OFF)
SET(DEAL_II_WITH_PETSC OFF)
SET(DEAL_II_WITH_SLEPC OFF)
SET(DEAL_II_WITH_THREADS ON)
SET(DEAL_II_WITH_TRILINOS OFF)
SET(DEAL_II_WITH_UMFPACK ON)
SET(DEAL_II_WITH_ZLIB ON)
